###############################################################
####
####  Script for Parker 2021, 
####  "On the Relationship between Frequency, Features, and Markedness in Inflection: Experimental Evidence from Russian Nouns" 
####  final version submitted July 2021
####
###############################################################


#### set up packages and read in data ####
require(lme4)
require(lmerTest)
require(dplyr)
require(ggplot2)
require(ggrepel)


## read in the experimental data
## data has already been trimmed: incorrect responses, low accuracy stimuli, low accuracy participants, outliers and responses to non-words have been removed
rt_data_trimmed<- read.delim(file="RT_results_clean_Parker2021.txt", sep="\t", encoding ="UTF-8", header = T)

#### modeling RT data ####

## model with all six 6 fix effects and random intercepts for subj and stimulus
## affix freq is sign; not lemma and not features
### this is the model reported in table 6 of paper
lmer_1_t<-lmer(data = rt_data_trimmed, REML=FALSE, log(RT) ~ (1|subj) + (1|stimulus) + log(form_freq+1) + form_len + order +  log(lemma_freq) + log(affix_freq) + log(features+1))
summary(lmer_1_t)

## same model with raw RT as dependent instead of log(RT); double checking for a reviewer that this doesn't change significance of results
lmer_1_t<-lmer(data = rt_data_trimmed, REML=FALSE, RT ~ (1|subj) + (1|stimulus) + log(form_freq+1) + form_len + order +  log(lemma_freq) + log(affix_freq) + log(features+1))
summary(lmer_1_t)

## without features
lmer_2_t<-lmer(data = rt_data_trimmed, REML=FALSE, log(RT) ~ (1|subj) + (1|stimulus) + log(form_freq+1) + form_len + order +  log(lemma_freq) + log(affix_freq))
summary(lmer_2_t)

## without affix frequency
lmer_2_t<-lmer(data = rt_data_trimmed, REML=FALSE, log(RT) ~ (1|subj) + (1|stimulus) + log(form_freq+1) + form_len + order +  log(lemma_freq)  + log(features+1))
summary(lmer_2_t)


#### looking at how it changes the model to treat class III locatives singulars (2 features) as nominative plurals (4 features) in terms of number of features ####
## reported in fn 17
rt_data_trimmed$features2 <- rt_data_trimmed$features
for (i in 1:nrow(rt_data_trimmed)){
  #print(i)
  if (rt_data_trimmed$suffix[i] == "y (sing)" & rt_data_trimmed$class[i] == "3"){
    #print ("chaning one value")
    #print (rt_data_trimmed$features[i])
    rt_data_trimmed$features2[i] <- 4
  }
}
## same model as above, just with new features column
lmer_1_t<-lmer(data = rt_data_trimmed, REML=FALSE, log(RT) ~ (1|subj) + (1|stimulus) + log(form_freq+1) + form_len + order +  log(lemma_freq) + log(affix_freq) + log(features2+1))
summary(lmer_1_t)
## just improves the importance of affix_freq

## with just features
lmer_1_t<-lmer(data = rt_data_trimmed, REML=FALSE, log(RT) ~ (1|subj) + (1|stimulus) + log(form_freq+1) + form_len + order +  log(lemma_freq) + log(features2+1))
summary(lmer_1_t)
## features still significant when affix frequency is not included, but not as important

#### checking to see if block1 vs block2 as factor matters ####
## see fn 14
for (i in 1:nrow(rt_data_trimmed)){
  if (rt_data_trimmed$MPS[i] == "loc_sg" | rt_data_trimmed$MPS[i] == "nom_sg"){
    rt_data_trimmed$group[i] <-"A"
  } else if (rt_data_trimmed$MPS[i] == "dat_pl" | rt_data_trimmed$MPS[i] == "inst_sg" | rt_data_trimmed$MPS[i] == "gen_pl"){
    rt_data_trimmed$group[i] <-"B"
  } else (print (paste0("Error: no match for i =", i)))
}
## block does not matter
lmer_1<-lmer(data = rt_data_trimmed, REML=FALSE, log(RT) ~ (1|subj) + (1|stimulus) + log(form_freq+1) + form_len + order +  log(lemma_freq) + group + log(affix_freq) + log(features+1))
summary(lmer_1)

#### looking at case, number and IC features separately ####
## see discussion in 5.4.1 of paper

## full model from above, for reference
lmer_1_t<-lmer(data = rt_data_trimmed, REML=FALSE, log(RT) ~ (1|subj) + (1|stimulus) + log(form_freq+1) + form_len + order +  log(lemma_freq) + log(affix_freq) + log(features+1))
summary(lmer_1_t)

## everything but affix freq
lmer_1_t<-lmer(data = rt_data_trimmed, REML=FALSE, log(RT) ~ (1|subj) + (1|stimulus) + form_len + order +  log(lemma_freq) + features_number + log(features_case+1) + log(features_IC+1))
summary(lmer_1_t)
## IC features not sign., all others are; model reported in paper

## looking at case and number features (labelled as features_MPS) in the aggregate data
### mean RT by features_MPS
data3<-aggregate(data=rt_data_trimmed, FUN=mean, RT ~ suffix + features_MPS)
data3<-data3[with(data3, order(RT)),]

model_feat_MPS <- lm (data3$RT ~ data3$features)
summary(model_feat_MPS)


##############################
##### visualizations #########
##############################

#### creating Figure 1 Correlation between affix frequency and affix features ####

## reading in corpus data/non-experimental data
data<-read.table(file="corpus_data_freq_features_Parker2021.txt",sep='\t', header=T) 
data2<-arrange(data,affix_freq)
## creating better and non-overlapping labels
affix_labels<-c("ju", "a[pl]", "am", "ax", "ami", "oj", "\U00D8[pl]", "e[2]", "om","o", "e[1]","ov/ej", "u", "i[pl]", "i[sg]", "a[sg]", "\U00D8[sg]")
data2$affix_lables<-affix_labels

## getting model info 
model_feat_freq <- lm (data2$features ~ log(data2$affix_freq))
summary(model_feat_freq)

## creating Figure 1 
features_and_frequency<-ggplot(data=data2, aes(x = log(affix_freq), y = features), label=affix_labels) +
  theme_bw() + 
  geom_point(size=.5) +
  geom_smooth(method="lm", se=FALSE, color = "gray", size=.5) +
  theme(axis.title=element_text(size=8), axis.text=element_text(size=6)) +
  labs(x="Log of affix frequency", y= "Number of affix features") +
  ## parse=TRUE needed to have subscripts and unicode
  geom_text_repel(label=affix_labels, parse=TRUE, box.padding = unit(0.6, "lines"), segment.color="gray", segment.size= .25, size=2.5) +
  
  annotate("text", x = 6.5, y = c(.75, .5, .25), parse = TRUE, size = 3,
           label = c("paste(italic(p), \" = 0.014\")", "paste(Adj., italic(R) ^2, \" = 0.295\")", "F(1,15)== 7.712"))
features_and_frequency

ggsave(
  "figure_1.png",features_and_frequency,
  width = 3.25,
  height = 3.25,
  dpi = 800
)


#### creating Figure 2 Effect of features on mean response time by affix ####
data3<-aggregate(data=rt_data_trimmed, FUN=mean, RT ~ suffix + features)
data3<-data3[with(data3, order(RT)),]
affix_labels<-c("\U00D8[sg]", "a[sg]", "i[sg]", "e[2]", "e[1]", "ju", "om", "\U00D8[pl]", "oj", "ov/ej", "am")
data3<-cbind(data3,affix_labels)

## getting model stats for plot
model_feat <- lm (data3$RT ~ data3$features)
summary(model_feat)

## creating figure
features_and_RT<-ggplot(data=data3, aes(x = features, y = RT), label=affix_labels) +
  theme_bw() + 
  geom_point(size=.5) +
  labs(x="Number of affix features", y= "Mean response time (ms)") +
  theme(axis.title=element_text(size=8), axis.text=element_text(size=6)) +
  ## parse=TRUE needed to have subscripts and unicode
  geom_smooth(method="lm", se=FALSE, color = "gray", size=.5) +
  geom_text_repel(label=affix_labels, parse=TRUE, box.padding = unit(0.6, "lines"), segment.color="gray", segment.size= .25, size=2.5) +
  annotate("text", x = 1, y = c(940, 925, 910), parse = TRUE, size = 3,
           label = c("paste(italic(p), \" = 0.001\")", "paste(Adj., italic(R) ^2, \" = 0.650\")", "paste(F(1,9), \"= 19.60\")"))
features_and_RT

ggsave(
  "figure_2.png",features_and_RT,
  width = 3.25,
  height = 3.25,
  dpi = 800
)


#### creating Figure 3 Effect of affix frequency on mean response time by affix ####

## mean RT by affix freq
data4<-aggregate(data=rt_data_trimmed, FUN=mean, RT ~ suffix + affix_freq)
data4<-data4[with(data4, order(RT)),]
affix_labels<-c("\U00D8[sg]", "a[sg]", "i[sg]", "e[2]", "e[1]", "ju", "om", "\U00D8[pl]", "oj", "ov/ej", "am")
data4<-cbind(data4,affix_labels)

## getting model stats for plot
model_freq <- lm (data4$RT ~ data4$affix_freq)
summary(model_freq)

affix_freq_and_RT<-ggplot(data=data4, aes(x = affix_freq, y = RT), label=affix_labels) +
  theme_bw() + 
  geom_point(size=.5) +
  ## to make the correlation in the same direction as features
  scale_x_reverse(labels = scales::comma) +
  labs(x="Affix frequency", y= "Mean response time (ms)") +
  theme(axis.title=element_text(size=8), axis.text=element_text(size=6)) +
  ## parse=TRUE needed to have subscripts and unicode
  geom_smooth(method="lm", se=FALSE, color = "gray", size=.5) +
  geom_text_repel(label=affix_labels, parse=TRUE, box.padding = unit(0.65, "lines"), segment.color="gray", segment.size= .25, size=2.5) +
  annotate("text", x = 7500, y = c(940, 925, 910), parse = TRUE, size = 3,
           label = c("paste(italic(p), \" < 0.001\")", "paste(Adj., italic(R) ^2, \" = 0.762\")", "paste(F(1,9), \"= 33.09\")")) 
  #scale_x_continuous(labels = scales::comma)
affix_freq_and_RT

ggsave(
  "figure_3.png",affix_freq_and_RT,
  width = 3.25,
  height = 3.25,
  dpi = 800
)

